==> flutter_snow_blower-0.0.1.tar.gz: lib/src/templates/start/src/mvc_modular/app_module.dart <==
String startAppModuleModular(String pkg) => '''
import 'package:$pkg/src/shared/clients/dio_client.dart';
import 'package:flutter/material.dart';
import 'package:flutter_modular/flutter_modular.dart';
import 'package:projectbasesnow/projectbasesnow.dart';

import 'app_widget.dart';
import 'modules/home/home_module.dart';

class AppModule extends MainModule {
  @override
  List<Bind> get binds => [
        Bind((i) => DioClient()),
        Bind<LocalStorage>((i) => LocalStorageHive()),
      ];

  @override
  List<Router> get routers => [
        Router(Modular.initialRoute, module: HomeModule()),
      ];

  @override
  Widget get bootstrap => AppWidget();

  static Inject get to => Inject<AppModule>.of();
}
  ''';

String startAppModuleModularComplete(String pkg) => '''
import 'package:flutter/material.dart';
import 'package:flutter_modular/flutter_modular.dart';
import 'package:$pkg/src/modules/login/login_module.dart';
import 'package:$pkg/src/shared/auth/auth_store.dart';
import 'package:$pkg/src/shared/auth/repositories/auth_repository.dart';
import 'package:$pkg/src/shared/auth/repositories/auth_repository_interface.dart';
import 'package:$pkg/src/shared/clients/dio_client.dart';
import 'package:projectbasesnow/projectbasesnow.dart';

import 'app_widget.dart';
import 'modules/home/home_module.dart';
import 'modules/splash/splash_page.dart';

class AppModule extends MainModule {
  @override
  List<Bind> get binds => [
        Bind((i) => DioClient()),
        Bind<AuthRepository>((i) => AuthRepositoryDefault()),
        Bind<LocalStorage>((i) => LocalStorageHive()),
        Bind((i) => AuthStore(), singleton: true),
      ];

  @override
  List<Router> get routers => [
        Router(
          Modular.initialRoute,
          child: (context, args) => SplashPage(),
          transition: TransitionType.noTransition,
        ),
        Router('/login',
            module: LoginModule()),
        Router('/home',
            module: HomeModule()),
      ];

  @override
  Widget get bootstrap => AppWidget();

  static Inject get to => Inject<AppModule>.of();
}
  ''';

==> flutter_snow_blower-0.1.1.tar.gz: lib/src/templates/start/src/mvc_modular/app_module.dart <==
String startAppModuleModular(String pkg) => '''
import 'package:$pkg/src/shared/clients/dio_client.dart';
import 'package:flutter/material.dart';
import 'package:flutter_modular/flutter_modular.dart';
import 'package:$pkg/src/shared/clients/hive_client.dart';

import 'app_widget.dart';
import 'modules/home/home_module.dart';

class AppModule extends MainModule {
  @override
  List<Bind> get binds => [
        Bind((i) => DioClient()),
        Bind((i) => HiveClient()),
      ];

  @override
  List<Router> get routers => [
        Router(Modular.initialRoute, module: HomeModule()),
      ];

  @override
  Widget get bootstrap => AppWidget();

  static Inject get to => Inject<AppModule>.of();
}
  ''';

String startAppModuleModularComplete(String pkg) => '''
import 'package:flutter/material.dart';
import 'package:flutter_modular/flutter_modular.dart';
import 'package:$pkg/src/modules/login/login_module.dart';
import 'package:$pkg/src/shared/auth/auth_store.dart';
import 'package:$pkg/src/shared/auth/repositories/auth_repository.dart';
import 'package:$pkg/src/shared/auth/repositories/auth_repository_interface.dart';
import 'package:$pkg/src/shared/clients/dio_client.dart';
import 'package:flutter_snow_base/flutter_snow_base.dart';
import 'package:$pkg/src/shared/clients/hive_client.dart';

import 'app_widget.dart';
import 'modules/home/home_module.dart';
import 'modules/splash/splash_page.dart';

class AppModule extends MainModule {
  @override
  List<Bind> get binds => [
        Bind((i) => DioClient()),
        Bind<AuthRepository>((i) => AuthRepositoryDefault()),
        Bind((i) => HiveClient()),
        Bind((i) => AuthStore(), singleton: true),
      ];

  @override
  List<Router> get routers => [
        Router(
          Modular.initialRoute,
          child: (context, args) => SplashPage(),
          transition: TransitionType.noTransition,
        ),
        Router('/login',
            module: LoginModule()),
        Router('/home',
            module: HomeModule()),
      ];

  @override
  Widget get bootstrap => AppWidget();

  static Inject get to => Inject<AppModule>.of();
}
  ''';
